@@ -94,5 +94,5 @@ void __bare_init __naked barebox_arm_reset_vector(void)
 	}
 
 out:
-	imx27_barebox_entry(0);
+	imx27_barebox_entry(NULL);
 }
