@@ -143,62 +143,3 @@ static int imx23_olinuxino_console_init(void)
 }
 
 console_initcall(imx23_olinuxino_console_init);
-
-/** @page olinuxino Olimex.ltd's i.MX23 evaluation kit
-
-This CPU card is based on an i.MX23 CPU. The card is shipped with:
-
-- 64 MiB synchronous dynamic RAM (mobile DDR type)
-
-
-Memory layout when @b barebox is running:
-
-- 0x40000000 start of SDRAM
-- 0x40000100 start of kernel's boot parameters
-  - below malloc area: stack area
-  - below barebox: malloc area
-- 0x42000000 start of @b barebox
-
-@section get_imx23_olinuxino_binary How to get the bootloader binary image:
-
-Using the default configuration:
-
-@verbatim
-make ARCH=arm imx23_olinuxino_defconfig
-@endverbatim
-
-Build the bootloader binary image:
-
-@verbatim
-make ARCH=arm CROSS_COMPILE=armv5compiler
-@endverbatim
-
-@note replace the armv5compiler with your ARM v5 cross compiler.
-
-@section imx233-olinuxino How to prepare an MCI card to boot
-the imx233-olinuxino with barebox
-
-- Create four primary partitions on the MCI card
- - the first one for the bootlets (about 256 kiB)
- - the second one for the persistant environment
-   (size is up to you, at least 256k)
- - the third one for the kernel (2 MiB ... 4 MiB in size)
- - the 4th one for the root filesystem which can fill the
-   rest of the available space
-
-- Mark the first partition with the partition ID "53" and copy the bootlets
-  into this partition (currently not part of @b barebox!).
-
-- @b barebox expect device tree blob file imx23-olinuxino.dtb
-  into directory env/oftree. At compile time, copy blob file into directory
-  arch/arm/boards/imx233-olinuxino/env/oftree/.
-
-- Copy the default @b barebox environment into the second partition
-  (no filesystem required).
-
-- Copy the kernel into the third partition (no filesystem required).
-
-- Create the root filesystem in the 4th partition. You may copy an
-  image into this partition or you can do it in the classic way:
-  mkfs on it, mount it and copy all required data and programs into it.
-*/
