@@ -13,7 +13,7 @@
 #include <sizes.h>
 #include <gpio.h>
 #include <asm/armlinux.h>
-#include <asm/hardware.h>
+#include <mach/hardware.h>
 #include <mach/board.h>
 #include <mach/at91_pmc.h>
 #include <mach/at91sam9x5_matrix.h>
