@@ -162,6 +162,22 @@ static void console_set_stdoutpath(struct console_device *cdev)
 	free(str);
 }
 
+static int __console_puts(struct console_device *cdev, const char *s)
+{
+	int n = 0;
+
+	while (*s) {
+		if (*s == '\n') {
+			cdev->putc(cdev, '\r');
+			n++;
+		}
+		cdev->putc(cdev, *s);
+		n++;
+		s++;
+	}
+	return n;
+}
+
 int console_register(struct console_device *newcdev)
 {
 	struct device_d *dev = &newcdev->class_dev;
@@ -170,8 +186,14 @@ int console_register(struct console_device *newcdev)
 	if (initialized == CONSOLE_UNINITIALIZED)
 		console_init_early();
 
-	dev->id = DEVICE_ID_DYNAMIC;
-	strcpy(dev->name, "cs");
+	if (newcdev->devname) {
+		dev->id = DEVICE_ID_SINGLE;
+		strcpy(dev->name, newcdev->devname);
+	} else {
+		dev->id = DEVICE_ID_DYNAMIC;
+		strcpy(dev->name, "cs");
+	}
+
 	if (newcdev->dev)
 		dev->parent = newcdev->dev;
 	platform_device_register(dev);
@@ -182,6 +204,9 @@ int console_register(struct console_device *newcdev)
 			NULL, &newcdev->baudrate, "%u", newcdev);
 	}
 
+	if (newcdev->putc && !newcdev->puts)
+		newcdev->puts = __console_puts;
+
 	dev_add_param(dev, "active", console_std_set, NULL, 0);
 
 	if (IS_ENABLED(CONFIG_CONSOLE_ACTIVATE_FIRST)) {
@@ -342,9 +367,19 @@ EXPORT_SYMBOL(console_putc);
 
 int console_puts(unsigned int ch, const char *str)
 {
+	struct console_device *cdev;
 	const char *s = str;
 	int n = 0;
 
+	if (initialized == CONSOLE_INIT_FULL) {
+		for_each_console(cdev) {
+			if (cdev->f_active & ch) {
+				n = cdev->puts(cdev, str);
+			}
+		}
+		return n;
+	}
+
 	while (*s) {
 		if (*s == '\n') {
 			console_putc(ch, '\r');
