@@ -301,8 +301,8 @@ static struct tegra_clk_init_table init_table[] = {
 static int tegra124_car_probe(struct device_d *dev)
 {
 	car_base = dev_request_mem_region(dev, 0);
-	if (!car_base)
-		return -EBUSY;
+	if (IS_ERR(car_base))
+		return PTR_ERR(car_base);
 
 	tegra124_osc_clk_init();
 	tegra124_pll_init();
