@@ -34,78 +34,6 @@
 #include <libgen.h>
 #include <block.h>
 
-void *read_file(const char *filename, size_t *size)
-{
-	int fd;
-	struct stat s;
-	void *buf = NULL;
-	const char *tmpfile = "/.read_file_tmp";
-	int ret;
-
-again:
-	if (stat(filename, &s))
-		return NULL;
-
-	if (s.st_size == FILESIZE_MAX) {
-		ret = copy_file(filename, tmpfile, 0);
-		if (ret)
-			return NULL;
-		filename = tmpfile;
-		goto again;
-	}
-
-	buf = xzalloc(s.st_size + 1);
-
-	fd = open(filename, O_RDONLY);
-	if (fd < 0)
-		goto err_out;
-
-	ret = read_full(fd, buf, s.st_size);
-	if (ret < 0)
-		goto err_out1;
-
-	close(fd);
-
-	if (size)
-		*size = s.st_size;
-
-	if (filename == tmpfile)
-		unlink(tmpfile);
-
-	return buf;
-
-err_out1:
-	close(fd);
-err_out:
-	free(buf);
-
-	if (filename == tmpfile)
-		unlink(tmpfile);
-
-	return NULL;
-}
-
-EXPORT_SYMBOL(read_file);
-
-int write_file(const char *filename, void *buf, size_t size)
-{
-	int fd, ret;
-
-	fd = open(filename, O_WRONLY | O_TRUNC | O_CREAT);
-	if (fd < 0)
-		return fd;
-
-	ret = write_full(fd, buf, size);
-
-	close(fd);
-
-	if (ret < 0)
-		return ret;
-
-	return 0;
-}
-EXPORT_SYMBOL(write_file);
-
 char *mkmodestr(unsigned long mode, char *str)
 {
 	static const char *l = "xwr";
